==> apache-superset-1.5.1-source.tar.gz: apache-superset-1.5.1rc1/superset-frontend/src/explore/components/DataTablesPane/DataTablesPane.test.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import React from 'react';
import userEvent from '@testing-library/user-event';
import fetchMock from 'fetch-mock';
import * as copyUtils from 'src/utils/copy';
import { render, screen } from 'spec/helpers/testing-library';
import { DataTablesPane } from '.';

const createProps = () => ({
  queryFormData: {
    viz_type: 'heatmap',
    datasource: '34__table',
    slice_id: 456,
    url_params: {},
    time_range_endpoints: ['unknown', 'inclusive'],
    time_range: 'Last week',
    all_columns_x: 'source',
    all_columns_y: 'target',
    metric: 'sum__value',
    adhoc_filters: [],
    row_limit: 10000,
    linear_color_scheme: 'blue_white_yellow',
    xscale_interval: null,
    yscale_interval: null,
    canvas_image_rendering: 'pixelated',
    normalize_across: 'heatmap',
    left_margin: 'auto',
    bottom_margin: 'auto',
    y_axis_bounds: [null, null],
    y_axis_format: 'SMART_NUMBER',
    show_perc: true,
    sort_x_axis: 'alpha_asc',
    sort_y_axis: 'alpha_asc',
    extra_form_data: {},
  },
  tableSectionHeight: 156.9,
  chartStatus: 'rendered',
  onCollapseChange: jest.fn(),
  queriesResponse: [
    {
      colnames: [],
    },
  ],
});

test('Rendering DataTablesPane correctly', () => {
  const props = createProps();
  render(<DataTablesPane {...props} />, { useRedux: true });
  expect(screen.getByTestId('some-purposeful-instance')).toBeVisible();
  expect(screen.getByRole('tablist')).toBeVisible();
  expect(screen.getByRole('tab', { name: 'right Data' })).toBeVisible();
  expect(screen.getByRole('img', { name: 'right' })).toBeVisible();
});

test('Should show tabs', async () => {
  const props = createProps();
  render(<DataTablesPane {...props} />, { useRedux: true });
  expect(screen.queryByText('View results')).not.toBeInTheDocument();
  expect(screen.queryByText('View samples')).not.toBeInTheDocument();
  userEvent.click(await screen.findByText('Data'));
  expect(await screen.findByText('View results')).toBeVisible();
  expect(screen.getByText('View samples')).toBeVisible();
});

test('Should show tabs: View results', async () => {
  const props = createProps();
  render(<DataTablesPane {...props} />, {
    useRedux: true,
  });
  userEvent.click(await screen.findByText('Data'));
  userEvent.click(await screen.findByText('View results'));
  expect(screen.getByText('0 rows retrieved')).toBeVisible();
});

test('Should show tabs: View samples', async () => {
  const props = createProps();
  render(<DataTablesPane {...props} />, {
    useRedux: true,
  });
  userEvent.click(await screen.findByText('Data'));
  expect(screen.queryByText('0 rows retrieved')).not.toBeInTheDocument();
  userEvent.click(await screen.findByText('View samples'));
  expect(await screen.findByText('0 rows retrieved')).toBeVisible();
});

test('Should copy data table content correctly', async () => {
  fetchMock.post(
    'glob:*/api/v1/chart/data?form_data=%7B%22slice_id%22%3A456%7D',
    {
      result: [
        {
          data: [{ __timestamp: 1230768000000, genre: 'Action' }],
          colnames: ['__timestamp', 'genre'],
          coltypes: [2, 1],
        },
      ],
    },
  );
  const copyToClipboardSpy = jest.spyOn(copyUtils, 'default');
  const props = createProps();
  render(
    <DataTablesPane
      {...{
        ...props,
        chartStatus: 'success',
        queriesResponse: [
          {
            colnames: ['__timestamp', 'genre'],
            coltypes: [2, 1],
          },
        ],
      }}
    />,
    {
      useRedux: true,
      initialState: {
        explore: {
          timeFormattedColumns: {
            '34__table': ['__timestamp'],
          },
        },
      },
    },
  );
  userEvent.click(await screen.findByText('Data'));
  expect(await screen.findByText('1 rows retrieved')).toBeVisible();

  userEvent.click(screen.getByRole('button', { name: 'Copy' }));
  expect(copyToClipboardSpy).toHaveBeenCalledWith(
    '2009-01-01 00:00:00\tAction\n',
  );
  fetchMock.done();
});

==> apache-superset-1.5.2-source.tar.gz: apache-superset-1.5.2rc3/superset-frontend/src/explore/components/DataTablesPane/DataTablesPane.test.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import React from 'react';
import userEvent from '@testing-library/user-event';
import fetchMock from 'fetch-mock';
import * as copyUtils from 'src/utils/copy';
import { render, screen } from 'spec/helpers/testing-library';
import { DataTablesPane } from '.';

const createProps = () => ({
  queryFormData: {
    viz_type: 'heatmap',
    datasource: '34__table',
    slice_id: 456,
    url_params: {},
    time_range_endpoints: ['unknown', 'inclusive'],
    time_range: 'Last week',
    all_columns_x: 'source',
    all_columns_y: 'target',
    metric: 'sum__value',
    adhoc_filters: [],
    row_limit: 10000,
    linear_color_scheme: 'blue_white_yellow',
    xscale_interval: null,
    yscale_interval: null,
    canvas_image_rendering: 'pixelated',
    normalize_across: 'heatmap',
    left_margin: 'auto',
    bottom_margin: 'auto',
    y_axis_bounds: [null, null],
    y_axis_format: 'SMART_NUMBER',
    show_perc: true,
    sort_x_axis: 'alpha_asc',
    sort_y_axis: 'alpha_asc',
    extra_form_data: {},
  },
  tableSectionHeight: 156.9,
  chartStatus: 'rendered',
  onCollapseChange: jest.fn(),
  queriesResponse: [
    {
      colnames: [],
    },
  ],
});

test('Rendering DataTablesPane correctly', () => {
  const props = createProps();
  render(<DataTablesPane {...props} />, { useRedux: true });
  expect(screen.getByTestId('some-purposeful-instance')).toBeVisible();
  expect(screen.getByRole('tablist')).toBeVisible();
  expect(screen.getByRole('tab', { name: 'right Data' })).toBeVisible();
  expect(screen.getByRole('img', { name: 'right' })).toBeVisible();
});

test('Should show tabs', async () => {
  const props = createProps();
  render(<DataTablesPane {...props} />, { useRedux: true });
  expect(screen.queryByText('View results')).not.toBeInTheDocument();
  expect(screen.queryByText('View samples')).not.toBeInTheDocument();
  userEvent.click(await screen.findByText('Data'));
  expect(await screen.findByText('View results')).toBeVisible();
  expect(screen.getByText('View samples')).toBeVisible();
});

test('Should show tabs: View results', async () => {
  const props = createProps();
  render(<DataTablesPane {...props} />, {
    useRedux: true,
  });
  userEvent.click(await screen.findByText('Data'));
  userEvent.click(await screen.findByText('View results'));
  expect(screen.getByText('0 rows retrieved')).toBeVisible();
});

test('Should show tabs: View samples', async () => {
  const props = createProps();
  render(<DataTablesPane {...props} />, {
    useRedux: true,
  });
  userEvent.click(await screen.findByText('Data'));
  expect(screen.queryByText('0 rows retrieved')).not.toBeInTheDocument();
  userEvent.click(await screen.findByText('View samples'));
  expect(await screen.findByText('0 rows retrieved')).toBeVisible();
});

test('Should copy data table content correctly', async () => {
  fetchMock.post(
    'glob:*/api/v1/chart/data?form_data=%7B%22slice_id%22%3A456%7D',
    {
      result: [
        {
          data: [{ __timestamp: 1230768000000, genre: 'Action' }],
          colnames: ['__timestamp', 'genre'],
          coltypes: [2, 1],
        },
      ],
    },
  );
  const copyToClipboardSpy = jest.spyOn(copyUtils, 'default');
  const props = createProps();
  render(
    <DataTablesPane
      {...{
        ...props,
        chartStatus: 'success',
        queriesResponse: [
          {
            colnames: ['__timestamp', 'genre'],
            coltypes: [2, 1],
          },
        ],
      }}
    />,
    {
      useRedux: true,
      initialState: {
        explore: {
          timeFormattedColumns: {
            '34__table': ['__timestamp'],
          },
        },
      },
    },
  );
  userEvent.click(await screen.findByText('Data'));
  expect(await screen.findByText('1 rows retrieved')).toBeVisible();

  userEvent.click(screen.getByRole('button', { name: 'Copy' }));
  expect(copyToClipboardSpy).toHaveBeenCalledTimes(1);
  const value = await copyToClipboardSpy.mock.calls[0][0]();
  expect(value).toBe('2009-01-01 00:00:00\tAction\n');
  copyToClipboardSpy.mockRestore();
  fetchMock.restore();
});
